︠506bb993-4f80-484b-8a28-ceac3d9e1ca5i︠
%md
## CoCalc Turtle Graphics using JSXGraph

Authors: Norbert Domes (sagenb version), William Stein (modified for CoCalc)

examples (sage code see below)
- [spirals](http://www.mathe-mit-sage.de/divers/spirals.html)
- [tree](href="http://www.mathe-mit-sage.de/divers/tree.html")

︡77796de5-551e-45d3-9cf5-b6a056a0b92d︡{"done":true,"md":"## CoCalc Turtle Graphics using JSXGraph\n\nAuthors: Norbert Domes (sagenb version), William Stein (modified for CoCalc)\n\nexamples (sage code see below)\n- [spirals](http://www.mathe-mit-sage.de/divers/spirals.html)\n- [tree](href=\"http://www.mathe-mit-sage.de/divers/tree.html\")"}
︠83b83042-43e7-49cb-ba75-f6ebdcbfb223a︠
def displacement(s,alpha):
    """
    returns the displacement vector with length s and
    direction alpha

    INPUT::

        s  -  number

        alpha  -  number (degrees from 0 to 360)

    """
    return s*vector(RR,(cos(pi*alpha/180),sin(pi*alpha/180)))


class Turtle():
    jsx_template = u"""
  <p><!-- JSXGraph MediaWiki extension 0.3.1 -->
  <link rel='stylesheet' type='text/css' href='http://jsxgraph.uni-bayreuth.de/distrib/jsxgraph.css' />
  <script src='https://cdnjs.cloudflare.com/ajax/libs/jsxgraph/0.99.5/jsxgraphcore.js' type='text/javascript'></script>
  <script src='https://cdnjs.cloudflare.com/ajax/libs/jsxgraph/0.99.5/geonext.min.js' type='text/javascript'></script>

  <div id='jxgbox-_id_' class='jxgbox' style='width:600px; height:600px;'></div>

<script type='text/javascript'>

// board options see JSXGraph reference
var brd = JXG.JSXGraph.initBoard('jxgbox-_id_', _board_options_ );

// create turtle at point (0,0) looking in direction 0
var t = brd.create('turtle',[[0,0],0]);

Code = _code_list_

function run() {
    eval(Code.shift());
    setTimeout(run,delay);
    if (Code.length < 1) return;
}

delay = _delay_;
run()

</script>
</p>
"""

    def __init__(self,board_options="{boundingbox:[-300,300,300,-300]}"):
        """
        create a new turtle and the 'board' to be moved on.

        the geometry of the board is fixed to 600x600px

        origin (0,0) in the center

        valid board options see JSXGraph reference

        set turtle to (0,0) and direction to 0 (turtle looking to the right)

        TODO::

            create more than one turtle on one board

        NOTE:

            only those python turtle methods with a counterpart in JSXGraph are implemented

        AUTHORS:

            Norbert Domes

        """
        import uuid
        self.html = Turtle.jsx_template.replace('_id_', str(uuid.uuid4())).replace('_board_options_',board_options)
        self.code = []
        self.position = vector((0,0))
        self.heading = 0

    def forward(self,x):
        """
        move turtle x units in turtle's direction
        """
        self.code.append("t.forward(%s);"%str(x))
        self.position += displacement(x,self.heading)
    fd = forward

    def backward(self,x):
        """
        move turtle x units backward to turtle's direction
        """
        self.code.append("t.back(%s);"%str(x))
        self.position -= displacement(x,self.heading)
    back = backward
    bk = backward

    def left(self,alpha):
        """
        turn turtle alpha degrees to the left

        ``alpha``  -  number
        """
        self.code.append("t.left(%s);"%str(alpha))
        self.heading += alpha
        self.heading = self.heading%360
    lt = left

    def right(self,alpha):
        """
        turn turtle alpha degrees to the right

        ``alpha``  -  number
        """
        self.code.append("t.right(%s);"%str(alpha))
        self.heading -= alpha
        self.heading = self.heading%360
    rt = right

    def setheading(self,alpha):
        """
        set turtle's direction (degrees from 0 to 360)

        ``alpha``  -  number
        """
        self.code.append("t.left(%s);"%str(alpha - self.heading))
        self.heading = alpha
        self.heading = self.heading%360

    def goto(self,*args):
        """
        move turtle to new position with drawing
        """
        if len(args) == 2:
            x = args[0]
            y = args[1]
        elif len(args)==1:
            x = args[0][0]
            y = args[0][1]
        else:
            raise ValueError('error message')
        self.code.append("t.moveTo(%s);"%str(list((x,y))))
        self.position  = vector((x,y))

    def setpos(self,*args):
        """
        move turtle to new position without drawing

        INPUT::

            x , y  -  two numbers

            or

            (x,y)  - pair of numbers

        """
        if len(args) == 2:
            x = args[0]
            y = args[1]
        elif len(args)==1:
            x = args[0][0]
            y = args[0][1]
        else:
            raise ValueError('error message')
        self.code.append("t.setPos(%s);"%str(list((x,y))))
        self.position  = vector((x,y))

    def penup(self):
        """
        further turtle movements without drawing
        """
        self.code.append("t.penUp();")
    pu = penup

    def pendown(self):
        """
        further turtle movements with drawing
        """
        self.code.append("t.penDown();")
    pd = pendown

    def home(self):
        """
        set turtle to (0,0) and direction to 0 (turtle looking to the right)
        """
        self.code.append("t.home();")
        self.position  = vector((0,0))
        self.heading = 0

    def clear(self):
        """
        erase all drawings
        not changing turtle's position and direction
        """
        self.code.append("t.clean();")

    def reset(self):
        """
        set turtle to (0,0) and direction to 0 (turtle looking to the right)
        and erase all drawings
        """
        self.code.append("t.clearScreen();")
        self.position  = vector((0,0))
        self.heading=0

    def hideturtle(self):
        """
        make turtle invisible
        """
        self.code.append("t.hideTurtle();")

    def showturtle(self):
        """
        make turtle visible
        """
        self.code.append("t.showTurtle();")

    def color(self,color):
        """
        set color of turtle's pen

        ``color``  -  color string like 'red' or '#ff0000'
        """
        self.code.append("t.setPenColor('%s');"%(color))

    def pensize(self,size):
        """
        set size of turtle's pen

        ``size``  -  integer
        """
        self.code.append("t.setPenSize(%s);"%(str(size)))

    def show(self, delay=10):
        """
        creates html file containing javascript code
        using JSXGraph library
        returns link to the file

        TODO:
            automatically reload html when changed
        """
        salvus.html(self.html.replace('_delay_',str(delay)).replace('_code_list_',str(self.code)))
︡e0ff9273-7bf2-46b9-b47c-1ced018158a2︡
︠94a3d4f3-f1fb-4dd1-9f25-10cec3eea852i︠
%md

### Spirals

︡5fc46c94-ee11-4cbe-ab23-83b0f908d49e︡{"done":true,"md":"\n### Spirals"}
︠69e22149-7056-4dc4-9547-2f80af42e436s︠
t = Turtle()
t.pensize(2)
t.color('red')
t.penup()
t.goto(0,100)
t.pendown()
t.left(90)
t.hideturtle()
for k in range(1,100):
    t.fd(10+k/6)
    t.rt(10)
t.color('green')
for k in range(1,100):
    t.fd(10+k/6)
    t.left(10)
t.show(delay=30)
︡0ee35fb1-2dc4-4612-9483-261d2ce3e999︡{"html":"\n  <p><!-- JSXGraph MediaWiki extension 0.3.1 -->\n  <link rel='stylesheet' type='text/css' href='http://jsxgraph.uni-bayreuth.de/distrib/jsxgraph.css' />\n  <script src='https://cdnjs.cloudflare.com/ajax/libs/jsxgraph/0.99.5/jsxgraphcore.js' type='text/javascript'></script>\n  <script src='https://cdnjs.cloudflare.com/ajax/libs/jsxgraph/0.99.5/geonext.min.js' type='text/javascript'></script>\n\n  <div id='jxgbox-fb5e338c-e83d-41c7-8943-b3f1f4419adc' class='jxgbox' style='width:600px; height:600px;'></div>\n\n<script type='text/javascript'>\n\n// board options see JSXGraph reference\nvar brd = JXG.JSXGraph.initBoard('jxgbox-fb5e338c-e83d-41c7-8943-b3f1f4419adc', {boundingbox:[-300,300,300,-300]} );\n\n// create turtle at point (0,0) looking in direction 0\nvar t = brd.create('turtle',[[0,0],0]);\n\nCode = ['t.setPenSize(2);', \"t.setPenColor('red');\", 't.penUp();', 't.moveTo([0, 100]);', 't.penDown();', 't.left(90);', 't.hideTurtle();', 't.forward(61/6);', 't.right(10);', 't.forward(31/3);', 't.right(10);', 't.forward(21/2);', 't.right(10);', 't.forward(32/3);', 't.right(10);', 't.forward(65/6);', 't.right(10);', 't.forward(11);', 't.right(10);', 't.forward(67/6);', 't.right(10);', 't.forward(34/3);', 't.right(10);', 't.forward(23/2);', 't.right(10);', 't.forward(35/3);', 't.right(10);', 't.forward(71/6);', 't.right(10);', 't.forward(12);', 't.right(10);', 't.forward(73/6);', 't.right(10);', 't.forward(37/3);', 't.right(10);', 't.forward(25/2);', 't.right(10);', 't.forward(38/3);', 't.right(10);', 't.forward(77/6);', 't.right(10);', 't.forward(13);', 't.right(10);', 't.forward(79/6);', 't.right(10);', 't.forward(40/3);', 't.right(10);', 't.forward(27/2);', 't.right(10);', 't.forward(41/3);', 't.right(10);', 't.forward(83/6);', 't.right(10);', 't.forward(14);', 't.right(10);', 't.forward(85/6);', 't.right(10);', 't.forward(43/3);', 't.right(10);', 't.forward(29/2);', 't.right(10);', 't.forward(44/3);', 't.right(10);', 't.forward(89/6);', 't.right(10);', 't.forward(15);', 't.right(10);', 't.forward(91/6);', 't.right(10);', 't.forward(46/3);', 't.right(10);', 't.forward(31/2);', 't.right(10);', 't.forward(47/3);', 't.right(10);', 't.forward(95/6);', 't.right(10);', 't.forward(16);', 't.right(10);', 't.forward(97/6);', 't.right(10);', 't.forward(49/3);', 't.right(10);', 't.forward(33/2);', 't.right(10);', 't.forward(50/3);', 't.right(10);', 't.forward(101/6);', 't.right(10);', 't.forward(17);', 't.right(10);', 't.forward(103/6);', 't.right(10);', 't.forward(52/3);', 't.right(10);', 't.forward(35/2);', 't.right(10);', 't.forward(53/3);', 't.right(10);', 't.forward(107/6);', 't.right(10);', 't.forward(18);', 't.right(10);', 't.forward(109/6);', 't.right(10);', 't.forward(55/3);', 't.right(10);', 't.forward(37/2);', 't.right(10);', 't.forward(56/3);', 't.right(10);', 't.forward(113/6);', 't.right(10);', 't.forward(19);', 't.right(10);', 't.forward(115/6);', 't.right(10);', 't.forward(58/3);', 't.right(10);', 't.forward(39/2);', 't.right(10);', 't.forward(59/3);', 't.right(10);', 't.forward(119/6);', 't.right(10);', 't.forward(20);', 't.right(10);', 't.forward(121/6);', 't.right(10);', 't.forward(61/3);', 't.right(10);', 't.forward(41/2);', 't.right(10);', 't.forward(62/3);', 't.right(10);', 't.forward(125/6);', 't.right(10);', 't.forward(21);', 't.right(10);', 't.forward(127/6);', 't.right(10);', 't.forward(64/3);', 't.right(10);', 't.forward(43/2);', 't.right(10);', 't.forward(65/3);', 't.right(10);', 't.forward(131/6);', 't.right(10);', 't.forward(22);', 't.right(10);', 't.forward(133/6);', 't.right(10);', 't.forward(67/3);', 't.right(10);', 't.forward(45/2);', 't.right(10);', 't.forward(68/3);', 't.right(10);', 't.forward(137/6);', 't.right(10);', 't.forward(23);', 't.right(10);', 't.forward(139/6);', 't.right(10);', 't.forward(70/3);', 't.right(10);', 't.forward(47/2);', 't.right(10);', 't.forward(71/3);', 't.right(10);', 't.forward(143/6);', 't.right(10);', 't.forward(24);', 't.right(10);', 't.forward(145/6);', 't.right(10);', 't.forward(73/3);', 't.right(10);', 't.forward(49/2);', 't.right(10);', 't.forward(74/3);', 't.right(10);', 't.forward(149/6);', 't.right(10);', 't.forward(25);', 't.right(10);', 't.forward(151/6);', 't.right(10);', 't.forward(76/3);', 't.right(10);', 't.forward(51/2);', 't.right(10);', 't.forward(77/3);', 't.right(10);', 't.forward(155/6);', 't.right(10);', 't.forward(26);', 't.right(10);', 't.forward(157/6);', 't.right(10);', 't.forward(79/3);', 't.right(10);', 't.forward(53/2);', 't.right(10);', \"t.setPenColor('green');\", 't.forward(61/6);', 't.left(10);', 't.forward(31/3);', 't.left(10);', 't.forward(21/2);', 't.left(10);', 't.forward(32/3);', 't.left(10);', 't.forward(65/6);', 't.left(10);', 't.forward(11);', 't.left(10);', 't.forward(67/6);', 't.left(10);', 't.forward(34/3);', 't.left(10);', 't.forward(23/2);', 't.left(10);', 't.forward(35/3);', 't.left(10);', 't.forward(71/6);', 't.left(10);', 't.forward(12);', 't.left(10);', 't.forward(73/6);', 't.left(10);', 't.forward(37/3);', 't.left(10);', 't.forward(25/2);', 't.left(10);', 't.forward(38/3);', 't.left(10);', 't.forward(77/6);', 't.left(10);', 't.forward(13);', 't.left(10);', 't.forward(79/6);', 't.left(10);', 't.forward(40/3);', 't.left(10);', 't.forward(27/2);', 't.left(10);', 't.forward(41/3);', 't.left(10);', 't.forward(83/6);', 't.left(10);', 't.forward(14);', 't.left(10);', 't.forward(85/6);', 't.left(10);', 't.forward(43/3);', 't.left(10);', 't.forward(29/2);', 't.left(10);', 't.forward(44/3);', 't.left(10);', 't.forward(89/6);', 't.left(10);', 't.forward(15);', 't.left(10);', 't.forward(91/6);', 't.left(10);', 't.forward(46/3);', 't.left(10);', 't.forward(31/2);', 't.left(10);', 't.forward(47/3);', 't.left(10);', 't.forward(95/6);', 't.left(10);', 't.forward(16);', 't.left(10);', 't.forward(97/6);', 't.left(10);', 't.forward(49/3);', 't.left(10);', 't.forward(33/2);', 't.left(10);', 't.forward(50/3);', 't.left(10);', 't.forward(101/6);', 't.left(10);', 't.forward(17);', 't.left(10);', 't.forward(103/6);', 't.left(10);', 't.forward(52/3);', 't.left(10);', 't.forward(35/2);', 't.left(10);', 't.forward(53/3);', 't.left(10);', 't.forward(107/6);', 't.left(10);', 't.forward(18);', 't.left(10);', 't.forward(109/6);', 't.left(10);', 't.forward(55/3);', 't.left(10);', 't.forward(37/2);', 't.left(10);', 't.forward(56/3);', 't.left(10);', 't.forward(113/6);', 't.left(10);', 't.forward(19);', 't.left(10);', 't.forward(115/6);', 't.left(10);', 't.forward(58/3);', 't.left(10);', 't.forward(39/2);', 't.left(10);', 't.forward(59/3);', 't.left(10);', 't.forward(119/6);', 't.left(10);', 't.forward(20);', 't.left(10);', 't.forward(121/6);', 't.left(10);', 't.forward(61/3);', 't.left(10);', 't.forward(41/2);', 't.left(10);', 't.forward(62/3);', 't.left(10);', 't.forward(125/6);', 't.left(10);', 't.forward(21);', 't.left(10);', 't.forward(127/6);', 't.left(10);', 't.forward(64/3);', 't.left(10);', 't.forward(43/2);', 't.left(10);', 't.forward(65/3);', 't.left(10);', 't.forward(131/6);', 't.left(10);', 't.forward(22);', 't.left(10);', 't.forward(133/6);', 't.left(10);', 't.forward(67/3);', 't.left(10);', 't.forward(45/2);', 't.left(10);', 't.forward(68/3);', 't.left(10);', 't.forward(137/6);', 't.left(10);', 't.forward(23);', 't.left(10);', 't.forward(139/6);', 't.left(10);', 't.forward(70/3);', 't.left(10);', 't.forward(47/2);', 't.left(10);', 't.forward(71/3);', 't.left(10);', 't.forward(143/6);', 't.left(10);', 't.forward(24);', 't.left(10);', 't.forward(145/6);', 't.left(10);', 't.forward(73/3);', 't.left(10);', 't.forward(49/2);', 't.left(10);', 't.forward(74/3);', 't.left(10);', 't.forward(149/6);', 't.left(10);', 't.forward(25);', 't.left(10);', 't.forward(151/6);', 't.left(10);', 't.forward(76/3);', 't.left(10);', 't.forward(51/2);', 't.left(10);', 't.forward(77/3);', 't.left(10);', 't.forward(155/6);', 't.left(10);', 't.forward(26);', 't.left(10);', 't.forward(157/6);', 't.left(10);', 't.forward(79/3);', 't.left(10);', 't.forward(53/2);', 't.left(10);']\n\nfunction run() {\n    eval(Code.shift());\n    setTimeout(run,delay);\n    if (Code.length < 1) return;\n}\n\ndelay = 30;\nrun()\n\n</script>\n</p>\n"}︡{"done":true}︡
︠a62df851-0a7f-4491-89f5-263a11745092i︠
%md

### Tree

︡0dbb18f9-52ac-4495-9b05-102f40ee7c17︡{"done":true,"md":"\n### Tree"}
︠18bc7b54-71c8-4293-8ad2-469d952171c4s︠
t = Turtle()
t.pensize(4)
t.color('pink')
t.hideturtle()

def tree(pos,dx,dy,n):
    if n <= 0:
        return
    x,y = pos
    pos_left = (x-dx,y-dy)
    pos_right = (x+dx,y-dy)
    t.setpos(pos)
    t.goto(pos_left)
    tree(pos_left,dx/2,4/5*dy,n-1)
    t.setpos(pos)
    t.goto(pos)
    t.goto(pos_right)
    tree(pos_right,dx/2,4/5*dy,n-1)

tree((0,200),128,80,5)
t.show()
︡a42aa582-fddc-44fe-ae2b-acff8f73d7e4︡{"html":"\n  <p><!-- JSXGraph MediaWiki extension 0.3.1 -->\n  <link rel='stylesheet' type='text/css' href='http://jsxgraph.uni-bayreuth.de/distrib/jsxgraph.css' />\n  <script src='https://cdnjs.cloudflare.com/ajax/libs/jsxgraph/0.99.5/jsxgraphcore.js' type='text/javascript'></script>\n  <script src='https://cdnjs.cloudflare.com/ajax/libs/jsxgraph/0.99.5/geonext.min.js' type='text/javascript'></script>\n\n  <div id='jxgbox-709289d1-7efc-47e0-93c4-f4a2f29c60a6' class='jxgbox' style='width:600px; height:600px;'></div>\n\n<script type='text/javascript'>\n\n// board options see JSXGraph reference\nvar brd = JXG.JSXGraph.initBoard('jxgbox-709289d1-7efc-47e0-93c4-f4a2f29c60a6', {boundingbox:[-300,300,300,-300]} );\n\n// create turtle at point (0,0) looking in direction 0\nvar t = brd.create('turtle',[[0,0],0]);\n\nCode = ['t.setPenSize(4);', \"t.setPenColor('pink');\", 't.hideTurtle();', 't.setPos([0, 200]);', 't.moveTo([-128, 120]);', 't.setPos([-128, 120]);', 't.moveTo([-192, 56]);', 't.setPos([-192, 56]);', 't.moveTo([-224, 24/5]);', 't.setPos([-224, 24/5]);', 't.moveTo([-240, -904/25]);', 't.setPos([-240, -904/25]);', 't.moveTo([-248, -8616/125]);', 't.setPos([-240, -904/25]);', 't.moveTo([-240, -904/25]);', 't.moveTo([-232, -8616/125]);', 't.setPos([-224, 24/5]);', 't.moveTo([-224, 24/5]);', 't.moveTo([-208, -904/25]);', 't.setPos([-208, -904/25]);', 't.moveTo([-216, -8616/125]);', 't.setPos([-208, -904/25]);', 't.moveTo([-208, -904/25]);', 't.moveTo([-200, -8616/125]);', 't.setPos([-192, 56]);', 't.moveTo([-192, 56]);', 't.moveTo([-160, 24/5]);', 't.setPos([-160, 24/5]);', 't.moveTo([-176, -904/25]);', 't.setPos([-176, -904/25]);', 't.moveTo([-184, -8616/125]);', 't.setPos([-176, -904/25]);', 't.moveTo([-176, -904/25]);', 't.moveTo([-168, -8616/125]);', 't.setPos([-160, 24/5]);', 't.moveTo([-160, 24/5]);', 't.moveTo([-144, -904/25]);', 't.setPos([-144, -904/25]);', 't.moveTo([-152, -8616/125]);', 't.setPos([-144, -904/25]);', 't.moveTo([-144, -904/25]);', 't.moveTo([-136, -8616/125]);', 't.setPos([-128, 120]);', 't.moveTo([-128, 120]);', 't.moveTo([-64, 56]);', 't.setPos([-64, 56]);', 't.moveTo([-96, 24/5]);', 't.setPos([-96, 24/5]);', 't.moveTo([-112, -904/25]);', 't.setPos([-112, -904/25]);', 't.moveTo([-120, -8616/125]);', 't.setPos([-112, -904/25]);', 't.moveTo([-112, -904/25]);', 't.moveTo([-104, -8616/125]);', 't.setPos([-96, 24/5]);', 't.moveTo([-96, 24/5]);', 't.moveTo([-80, -904/25]);', 't.setPos([-80, -904/25]);', 't.moveTo([-88, -8616/125]);', 't.setPos([-80, -904/25]);', 't.moveTo([-80, -904/25]);', 't.moveTo([-72, -8616/125]);', 't.setPos([-64, 56]);', 't.moveTo([-64, 56]);', 't.moveTo([-32, 24/5]);', 't.setPos([-32, 24/5]);', 't.moveTo([-48, -904/25]);', 't.setPos([-48, -904/25]);', 't.moveTo([-56, -8616/125]);', 't.setPos([-48, -904/25]);', 't.moveTo([-48, -904/25]);', 't.moveTo([-40, -8616/125]);', 't.setPos([-32, 24/5]);', 't.moveTo([-32, 24/5]);', 't.moveTo([-16, -904/25]);', 't.setPos([-16, -904/25]);', 't.moveTo([-24, -8616/125]);', 't.setPos([-16, -904/25]);', 't.moveTo([-16, -904/25]);', 't.moveTo([-8, -8616/125]);', 't.setPos([0, 200]);', 't.moveTo([0, 200]);', 't.moveTo([128, 120]);', 't.setPos([128, 120]);', 't.moveTo([64, 56]);', 't.setPos([64, 56]);', 't.moveTo([32, 24/5]);', 't.setPos([32, 24/5]);', 't.moveTo([16, -904/25]);', 't.setPos([16, -904/25]);', 't.moveTo([8, -8616/125]);', 't.setPos([16, -904/25]);', 't.moveTo([16, -904/25]);', 't.moveTo([24, -8616/125]);', 't.setPos([32, 24/5]);', 't.moveTo([32, 24/5]);', 't.moveTo([48, -904/25]);', 't.setPos([48, -904/25]);', 't.moveTo([40, -8616/125]);', 't.setPos([48, -904/25]);', 't.moveTo([48, -904/25]);', 't.moveTo([56, -8616/125]);', 't.setPos([64, 56]);', 't.moveTo([64, 56]);', 't.moveTo([96, 24/5]);', 't.setPos([96, 24/5]);', 't.moveTo([80, -904/25]);', 't.setPos([80, -904/25]);', 't.moveTo([72, -8616/125]);', 't.setPos([80, -904/25]);', 't.moveTo([80, -904/25]);', 't.moveTo([88, -8616/125]);', 't.setPos([96, 24/5]);', 't.moveTo([96, 24/5]);', 't.moveTo([112, -904/25]);', 't.setPos([112, -904/25]);', 't.moveTo([104, -8616/125]);', 't.setPos([112, -904/25]);', 't.moveTo([112, -904/25]);', 't.moveTo([120, -8616/125]);', 't.setPos([128, 120]);', 't.moveTo([128, 120]);', 't.moveTo([192, 56]);', 't.setPos([192, 56]);', 't.moveTo([160, 24/5]);', 't.setPos([160, 24/5]);', 't.moveTo([144, -904/25]);', 't.setPos([144, -904/25]);', 't.moveTo([136, -8616/125]);', 't.setPos([144, -904/25]);', 't.moveTo([144, -904/25]);', 't.moveTo([152, -8616/125]);', 't.setPos([160, 24/5]);', 't.moveTo([160, 24/5]);', 't.moveTo([176, -904/25]);', 't.setPos([176, -904/25]);', 't.moveTo([168, -8616/125]);', 't.setPos([176, -904/25]);', 't.moveTo([176, -904/25]);', 't.moveTo([184, -8616/125]);', 't.setPos([192, 56]);', 't.moveTo([192, 56]);', 't.moveTo([224, 24/5]);', 't.setPos([224, 24/5]);', 't.moveTo([208, -904/25]);', 't.setPos([208, -904/25]);', 't.moveTo([200, -8616/125]);', 't.setPos([208, -904/25]);', 't.moveTo([208, -904/25]);', 't.moveTo([216, -8616/125]);', 't.setPos([224, 24/5]);', 't.moveTo([224, 24/5]);', 't.moveTo([240, -904/25]);', 't.setPos([240, -904/25]);', 't.moveTo([232, -8616/125]);', 't.setPos([240, -904/25]);', 't.moveTo([240, -904/25]);', 't.moveTo([248, -8616/125]);']\n\nfunction run() {\n    eval(Code.shift());\n    setTimeout(run,delay);\n    if (Code.length < 1) return;\n}\n\ndelay = 10;\nrun()\n\n</script>\n</p>\n"}︡{"done":true}︡









